/*!
 * @file        apm32f10x_it.c
 *
 * @brief       Main Interrupt Service Routines
 *
 * @version     V1.0.0
 *
 * @date        2019-9-30
 *
 */

#include "apm32f10x_it.h"
#include "board.h"
#include "apm32f10x_eint.h"
#include "main.h"
#include "misc.h"
/*!
 * @brief   This function handles NMI exception   
 *
 * @param   None
 *
 * @retval  None
 *
 */     
void NMI_Handler(void)
{
}

/*!
 * @brief   This function handles Hard Fault exception  
 *
 * @param   None
 *
 * @retval  None
 *
 */ 
void HardFault_Handler(void)
{
    /* Go to infinite loop when Hard Fault exception occurs */
    while (1)
    {
    }
}

/*!
 * @brief   This function handles Memory Manage exception  
 *
 * @param   None
 *
 * @retval  None
 *
 */
void MemManage_Handler(void)
{
    /* Go to infinite loop when Memory Manage exception occurs */
    while (1)
    {
    }
}

/*!
 * @brief   This function handles Bus Fault exception  
 *
 * @param   None
 *
 * @retval  None
 *
 */
void BusFault_Handler(void)
{
    /* Go to infinite loop when Bus Fault exception occurs */
    while (1)
    {
    }
}
/*!
 * @brief   This function handles Usage Fault exception 
 *
 * @param   None
 *
 * @retval  None
 *
 */
void UsageFault_Handler(void)
{
    /* Go to infinite loop when Usage Fault exception occurs */
    while (1)
    {
    }
}

/*!
 * @brief   This function handles SVCall exception 
 *
 * @param   None
 *
 * @retval  None
 *
 */
void SVC_Handler(void)
{
}

/*!
 * @brief   This function handles Debug Monitor exception 
 *
 * @param   None
 *
 * @retval  None
 *
 */
void DebugMon_Handler(void)
{
}

/*!
 * @brief   This function handles PendSV_Handler exception 
 *
 * @param   None
 *
 * @retval  None
 *
 */

void PendSV_Handler(void)
{
}

/*!
 * @brief   This function handles SysTick Handler 
 *
 * @param   None
 *
 * @retval  None
 *
 */
void SysTick_Handler(void)
{
    if(NVIC_GetActive(WAKEUP_BUTTON_EXTI_IRQn) != 0)
    {
        PreemptionOccured = 1;
    }
}

/*!
 * @brief   This function handles External lines 9 to 5 request
 *
 * @param   None
 *
 * @retval  None
 *
 */
void EINT9_5_IRQHandler(void)
{   
    if(EINT_ReadIntFlag(KEY_BUTTON_EXTI_LINE) != RESET)
    {
        PreemptionPriorityValue = !PreemptionPriorityValue;
        PreemptionOccured = 0;
        
        NVIC_EnableIRQRequest(WAKEUP_BUTTON_EXTI_IRQn, PreemptionPriorityValue, 0);
        NVIC_SetPriority(SysTick_IRQn, NVIC_EncodePriority(NVIC_GetPriorityGrouping(), !PreemptionPriorityValue, 0));    
        
        EINT_ClearIntFlag(KEY_BUTTON_EXTI_LINE);
    }
}

/*!
 * @brief   This function handles External interrupt Line 0 request
 *
 * @param   None
 *
 * @retval  None
 *
 */
void EINT0_IRQHandler(void)
{   
    SCB->ICSR |= 0x04000000;
    EINT_ClearIntFlag(WAKEUP_BUTTON_EXTI_LINE); 
}
